<?php
/*
Plugin Name: Модуль вывода текущего исполнителя и обложки для Radio Boss
Plugin URI: https://www.radiorecord.com.ua/
Description: Виджет для отображения текущего трека, обложки и истории треков.
Version: 1.3
Author: LLC IA Radio Record Ukraine
Author URI: https://www.radiorecord.com.ua/
License: GPL2
*/

if (!defined('ABSPATH')) {
    exit;
}

// Пути к файлам
define('RADIO_RECORD_HISTORY_FILE', plugin_dir_path(__FILE__) . 'history.txt');

// Получение текущего трека и истории
function radio_record_get_now_playing() {
    $track_url = 'https://www.radiorecord.com.ua/nowplaying/nowplaying.txt';
    $artwork_url = 'https://www.radiorecord.com.ua/nowplaying/nowplaying_artwork.png?' . time();

    // Получаем название текущего трека
    $response = wp_remote_get($track_url);
    if (is_wp_error($response)) {
        return ['error' => 'Ошибка загрузки трека'];
    }

    $track_name = esc_html(trim(wp_remote_retrieve_body($response)));
    if (!$track_name) return ['error' => 'Трек не найден'];

    // Записываем историю
    $history = [];
    if (file_exists(RADIO_RECORD_HISTORY_FILE)) {
        $history = file(RADIO_RECORD_HISTORY_FILE, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
    }

    // Обновляем историю (удаляем дубликаты, оставляем 5 последних)
    if (!in_array($track_name, $history)) {
        array_unshift($history, $track_name);
        $history = array_slice($history, 0, 5);
        file_put_contents(RADIO_RECORD_HISTORY_FILE, implode("\n", $history));
    }

    return [
        'track' => $track_name,
        'artwork' => $artwork_url,
        'history' => $history
    ];
}

// Вывод HTML-кода виджета
function radio_record_widget_output() {
    return '<div class="radio-record-container">
                <div id="radio-record-content">
                    <img id="radio-record-artwork" src="" alt="Now Playing">
                     <h3>ЗАРАЗ ЛУНАЄ</h3>
                    <p id="radio-record-track">Завантаження...</p>
                </div>
                <h4>ІСТОРІЯ ТРЕКІВ</h4>
                <ul id="radio-record-history"></ul>
            </div>';
}

// Регистрация шорткода
function radio_record_shortcode() {
    return radio_record_widget_output();
}
add_shortcode('radio_now_playing', 'radio_record_shortcode');

// Виджет-класс
class Radio_Record_Widget extends WP_Widget {
    function __construct() {
        parent::__construct('radio_record_widget', __('Radio Record Now Playing', 'text_domain'), [
            'description' => __('Виджет для отображения текущего трека и истории', 'text_domain')
        ]);
    }

    public function widget($args, $instance) {
        echo $args['before_widget'];
        echo radio_record_widget_output();
        echo $args['after_widget'];
    }
}

// Регистрация виджета
function register_radio_record_widget() {
    register_widget('Radio_Record_Widget');
}
add_action('widgets_init', 'register_radio_record_widget');

// Подключение стилей и JS
function radio_record_enqueue_assets() {
    wp_enqueue_style('radio-record-style', plugin_dir_url(__FILE__) . 'assets/style.css');
    wp_enqueue_script('radio-record-script', plugin_dir_url(__FILE__) . 'assets/script.js', ['jquery'], null, true);

    wp_localize_script('radio-record-script', 'radioRecordAjax', [
        'ajaxurl' => admin_url('admin-ajax.php')
    ]);
}
add_action('wp_enqueue_scripts', 'radio_record_enqueue_assets');

// AJAX обработчик обновления
function radio_record_ajax_update() {
    echo json_encode(radio_record_get_now_playing());
    wp_die();
}
add_action('wp_ajax_radio_record_update', 'radio_record_ajax_update');
add_action('wp_ajax_nopriv_radio_record_update', 'radio_record_ajax_update');
